@@ -155,11 +155,16 @@ gboolean	 as_store_load_path		(AsStore	*store,
 						 GError		**error);
 void		 as_store_remove_all		(AsStore	*store);
 GPtrArray	*as_store_get_apps		(AsStore	*store);
+GPtrArray	*as_store_get_apps_by_id	(AsStore	*store,
+						 const gchar	*id);
 GPtrArray	*as_store_get_apps_by_metadata	(AsStore	*store,
 						 const gchar	*key,
 						 const gchar	*value);
 AsApp		*as_store_get_app_by_id		(AsStore	*store,
 						 const gchar	*id);
+AsApp		*as_store_get_app_by_id_ignore_prefix
+						(AsStore	*store,
+						 const gchar	*id);
 AsApp		*as_store_get_app_by_id_with_fallbacks (AsStore	*store,
 						 const gchar	*id);
 AsApp		*as_store_get_app_by_pkgname	(AsStore	*store,
